@@ -15,7 +15,7 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 # 02111-1307, USA.
 #
-"""CPS Layer for funkload test.
+"""FunkLoad test case for Nuxeo CPS.
 
 $Id: CPSTestCase.py 24728 2005-08-31 08:13:54Z bdelbosc $
 """
@@ -298,7 +298,7 @@ class CPSTestCase(ZopeTestCase):
         params = [["SearchableText", doc_id]]
         self.post("%s/search_form" % self.server_url, params,
                   description="Searching doc_id %s" % doc_id)
-        ret = self.listDocumentHref(pattern='%s$' % doc_id)
+        ret = self.cpsListDocumentHref(pattern='%s$' % doc_id)
         self.logd('found %i link ends with %s' % (len(ret), doc_id))
         return ret
 
@@ -315,7 +315,7 @@ class CPSTestCase(ZopeTestCase):
                 url = url[len(server_url):]
         return url
 
-    def listDocumentHref(self, pattern=None):
+    def cpsListDocumentHref(self, pattern=None):
         """Return a clean list of document href that matches pattern.
 
         Try to remove server_url and other cps trailings,
