@@ -15,7 +15,7 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 # 02111-1307, USA.
 #
-"""Classes that collect and render statistics submitted by the result parser.
+"""Classes that collect statistics submitted by the result parser.
 
 $Id: ReportStats.py 24737 2005-08-31 09:00:16Z bdelbosc $
 """
@@ -148,6 +148,8 @@ class PageStat(AllResponseStat):
 
     def finalize(self):
         """Compute avg times."""
+        if self.finalized:
+            return
         for thread in self.threads.keys():
             for page in self.threads[thread]['pages'].values():
                 #print "page ", page
@@ -167,7 +169,7 @@ class PageStat(AllResponseStat):
         if self.cycle_duration:
             # override rps to srps
             self.rps = self.success / float(self.cycle_duration)
-
+        self.finalized = True
 
 class ResponseStat:
     """Collect stat a specific response in a cycle."""
